This project is archived and is in readonly mode.
Changeset [c5bfc6abe4fd160814f09b02afe68d7f4e25e3d6] by Neeraj Singh
Revision c5bfc6abe4fd160814f09b02afe68d7f4e25e3d6,
committed by Neeraj Singh
· November 22nd, 2010 @ 10:06 PM
string include method is 10x faster than creating
a new regex object every single time
Signed-off-by: José Valim jose.valim@gmail.com
https://github.com/rails/rails/commit/c5bfc6abe4fd160814f09b02afe68...
1 changed file
-
M
actionpack/lib/action_dispatch/http/mime_type.rb